@@ -49,16 +49,15 @@ using namespace camitk;
 ImageLutWidget::ImageLutWidget(QWidget* parent) : QWidget( parent) {
 
     myComponent = NULL;
+
+    lutMin = 0;
+    lutMax = 255;
     nbHistoBins = 256;
-    greyLevels = new unsigned int[nbHistoBins];
+    greyLevels = NULL;
 
     // Qt model designed by QtDesigner (with qt4, nor more inheritance from the ui)
     ui.setupUi ( this );
 
-    // initialize the sliders value
-    lutMin = 0;
-    lutMax = 255;
-
     initSlider ( ui.sliderLutLevel, lutMin, lutMax, (lutMax - lutMin) / 2.0 );
     initSlider ( ui.sliderLutWindow, 0, ( lutMax - lutMin ), (lutMax - lutMin - 0.0) / 2.0 );
 
@@ -93,6 +92,7 @@ void ImageLutWidget::updateComponent(ImageComponent * comp) {
 
     myComponent = comp;
 
+
     // if there is no lookup table, just don't display this widget!
     if (myComponent->getLut() == NULL) {
         setEnabled(false);
@@ -106,25 +106,42 @@ void ImageLutWidget::updateComponent(ImageComponent * comp) {
 
     // initialize the sliders value
 //    int nbOfColors = myComponent->getLut()->GetNumberOfTableValues();
-	double * imgRange = myComponent->getImageData()->GetScalarRange();
-	double imgMinColor = imgRange[0];
-	double imgMaxColor = imgRange[1];
+    double * imgRange = myComponent->getImageData()->GetScalarRange();
+    double imgMinColor = imgRange[0];
+    double imgMaxColor = imgRange[1];
+
+
 
 //	double imgMinColor = myComponent->getImageData()->get GetScalarTypeMin();
 //	double imgMaxColor = myComponent->getImageData()->GetScalarTypeMax();
-	double nbColorsOrg = imgMaxColor - imgMinColor;
-	long int nbOfColors = (long int) (nbColorsOrg);
+    double nbColorsOrg = imgMaxColor - imgMinColor;
+    long int nbOfColors = (long int) (nbColorsOrg);
 
     // as this widget is only grayscale, compute the average of the color values
 //    lutMin = myComponent->getImageData()->GetScalarTypeMin();
 //    lutMax = myComponent->getImageData()->GetScalarTypeMax();
-	lutMin = imgMinColor;
-	lutMax = imgMaxColor;
+    lutMin = imgMinColor;
+    lutMax = imgMaxColor;
+
+    // update scale and table value information on the luts
+    nbHistoBins = abs(lutMin) + abs(lutMax);
+    myComponent->getLut()->SetNumberOfTableValues(nbHistoBins);
+    myComponent->getLut()->SetLevel((imgMinColor + imgMaxColor) /2);
+    myComponent->getLut()->SetWindow((imgMaxColor - imgMinColor) /2);
 
     blockAllSignals ( true );
     initLevelGUI(lutMin, lutMax, myComponent->getLut()->GetLevel());
     initWindowGUI( 0, ( lutMax - lutMin ), myComponent->getLut()->GetWindow());
 
+    // allocate memory to draw the histogram according to the number of available scalar component
+    // free memory of previously drawn histogram if the lut widget handle another component
+    if (greyLevels)
+        delete greyLevels;
+
+    // allocate the memory needed for that component
+    greyLevels = new unsigned int[nbHistoBins + 1];
+
+
     // check alpha state for min and max
     double * color = myComponent->getLut()->GetTableValue(0);
     QColor minColor = QColor::fromRgbF(color[0], color[1], color[2], 1.0);
@@ -151,8 +168,9 @@ void ImageLutWidget::updateComponent(ImageComponent * comp) {
 
 //---------------------- updateLUT ------------------------
 void ImageLutWidget::applyLUT() {
-    // update window and level
-    myComponent->getLut()->SetWindow (  ui.lineEditLutWindow->text().toInt() );
+
+    // set window level and width according to user set up
+    myComponent->getLut()->SetWindow ( ui.lineEditLutWindow->text().toInt() );
     myComponent->getLut()->SetLevel ( ui.lineEditLutLevel->text().toInt() );
 
     // use the color to update table values
@@ -180,6 +198,7 @@ void ImageLutWidget::applyLUT() {
     myComponent->getLut()->SetTableValue(nbOfColors - 1, maxColor.redF(), maxColor.greenF(), maxColor.blueF(), (ui.maxTransparency->isChecked() ? 0.0 : 1.0));
 
     myComponent->refresh();
+
     draw();
 }
 
@@ -204,8 +223,9 @@ void ImageLutWidget::resetLUT() {
 
 //---------------------- draw ------------------------
 void ImageLutWidget::draw () {
+
     //-- initialize histogram values to 0
-    for (int i = 0; i < nbHistoBins; i++ )
+    for (unsigned int i = 0; i < nbHistoBins; i++ )
         greyLevels[i] = 0;
 
     //-- get image volume
@@ -230,35 +250,35 @@ void ImageLutWidget::draw () {
     case VTK_CHAR:
     case VTK_SIGNED_CHAR:
         fillHistogramTable<char> ( ( char * ) data->GetScalarPointer(), totalDim,
-                                   data->GetScalarTypeMin(), data->GetScalarTypeMax());
+                                   (char) lutMin, (char) lutMax);
         break;
     case VTK_UNSIGNED_CHAR:
         fillHistogramTable<unsigned char> ( ( unsigned char * ) data->GetScalarPointer(), totalDim,
-                                            data->GetScalarTypeMin(), data->GetScalarTypeMax());
+                                            (unsigned char) lutMin, (unsigned char) lutMax);
         break;
     case VTK_SHORT:
         fillHistogramTable<short> ( ( short * ) data->GetScalarPointer(), totalDim,
-                                    data->GetScalarTypeMin(), data->GetScalarTypeMax());
+                                    (short) lutMin, (short) lutMax);
         break;
     case VTK_UNSIGNED_SHORT:
         fillHistogramTable<unsigned short> ( ( unsigned short * ) data->GetScalarPointer(), totalDim,
-                                             data->GetScalarTypeMin(), data->GetScalarTypeMax());
+                                             (unsigned short) lutMin, (unsigned short) lutMax);
         break;
     case VTK_INT:
         fillHistogramTable<int> ( ( int * ) data->GetScalarPointer(), totalDim,
-                                  data->GetScalarTypeMin(), data->GetScalarTypeMax());
+                                  (int) lutMin, (int) lutMax);
         break;
     case VTK_UNSIGNED_INT:
         fillHistogramTable<unsigned int> ( ( unsigned int * ) data->GetScalarPointer(), totalDim,
-                                           data->GetScalarTypeMin(), data->GetScalarTypeMax() );
+                                           (unsigned int) lutMin, (unsigned int) lutMax);
         break;
     case VTK_FLOAT:
         fillHistogramTable<float> ( ( float * ) data->GetScalarPointer(), totalDim,
-                                    data->GetScalarTypeMin(), data->GetScalarTypeMax() );
+                                    (float) lutMin, (float) lutMax);
         break;
     case VTK_DOUBLE:
         fillHistogramTable<double> ( ( double * ) data->GetScalarPointer(), totalDim,
-                                     data->GetScalarTypeMin(), data->GetScalarTypeMax());
+                                     (double) lutMin, (double) lutMax);
         break;
     }
 
@@ -269,7 +289,8 @@ void ImageLutWidget::draw () {
     pen.setColor(palette().background().color());
 
     //-- background color
-    QRectF sceneRectangle(0.0, 0.0, 250.0, 250.0);
+//     QRectF sceneRectangle(0.0, 0.0, 250.0, 250.0); <-- old rectangle for 0->255 pixel values
+    QRectF sceneRectangle(lutMin, 0.0, nbHistoBins, highestGreyLevel);
 
     //-- draw color table
     QLinearGradient colorGradient(sceneRectangle.x(), sceneRectangle.height() / 2.0, sceneRectangle.width(), sceneRectangle.height() / 2.0);
@@ -286,6 +307,7 @@ void ImageLutWidget::draw () {
     ui.histogramGraphicsView->scene()->addItem(sceneRectItem);
 
     //-- show transparency
+    //BEGIN
     double window = myComponent->getLut()->GetWindow();
     double level = myComponent->getLut()->GetLevel();
     if (ui.maxTransparency->isChecked()) {
@@ -300,53 +322,51 @@ void ImageLutWidget::draw () {
             ui.histogramGraphicsView->scene()->addRect(sceneRectangle.x(), sceneRectangle.y(), minCorner.x(), sceneRectangle.height(), pen, QBrush(palette().window()));
         }
     }
+    //END
 
     //-- draw histogram
-    double barHeight;
-    double barWidth = sceneRectangle.width() / double(nbHistoBins);
+    //BEGIN
+    qreal barHeight;
+    qreal barWidth = 1.0; //sceneRectangle.width() / double(nbHistoBins);
     double x = sceneRectangle.x();
     QPainterPath histogramPath(QPointF(x, sceneRectangle.height()));
-    for (int i = 0; i < nbHistoBins; i++ ) {
-        barHeight = greyLevels[i] * sceneRectangle.height() / double(highestGreyLevel);
+    for (unsigned int i = 0; i < nbHistoBins; i++ ) {
+        barHeight = greyLevels[i]; // * sceneRectangle.height() / double(highestGreyLevel);
         histogramPath.lineTo(x, sceneRectangle.height() - barHeight);
         x += barWidth;
     }
     histogramPath.lineTo(sceneRectangle.width(), sceneRectangle.height());
     histogramPath.lineTo(x, sceneRectangle.height());
     pen.setColor(Qt::white);
-    ui.histogramGraphicsView->scene()->addPath(histogramPath, pen, Qt::black);
+    ui.histogramGraphicsView->scene()->addPath(histogramPath, pen, Qt::blue);
 
     //-- draw lut level and window
     pen.setColor(Qt::darkGreen);
     pen.setStyle(Qt::DashLine);
-    pen.setWidth(2);
+
+    // pen width depends on numbers of bars in the histogram
+    int penWidth = (int)((double)nbHistoBins / 100.0);
+    //END
+
+//     pen.setWidth(2);
+    pen.setWidth(penWidth);
+
     ui.histogramGraphicsView->scene()->addLine(level, sceneRectangle.y(), level, sceneRectangle.height(), pen);
 
     pen.setStyle(Qt::SolidLine);
     // create the proper path for the LUT
-    QPointF leftCorner(sceneRectangle.x() + level - window / 2.0, sceneRectangle.height());
+    //BEGIN
+    // QPointF leftCorner(sceneRectangle.x() + level - window / 2.0, sceneRectangle.height());
+    QPointF leftCorner(level - window / 2.0, sceneRectangle.height());
+    QPointF rightCorner(level + window / 2.0, sceneRectangle.y());
     QPainterPath path;
-    if (leftCorner.x() < sceneRectangle.x()) {
-        // find intersection
-        leftCorner.setY(sceneRectangle.height() + leftCorner.x());
-        leftCorner.setX(sceneRectangle.x());
-        path.moveTo(leftCorner);
-    }
-    else {
-        path.moveTo(sceneRectangle.x(), sceneRectangle.height());
-        path.lineTo(leftCorner);
-    }
-    QPointF rightCorner(sceneRectangle.x() + level + window / 2.0, sceneRectangle.y());
-    if (rightCorner.x() > sceneRectangle.width()) {
-        // find intersection
-        rightCorner.setY(sceneRectangle.width() - rightCorner.x());
-        rightCorner.setX(sceneRectangle.width());
-        path.lineTo(rightCorner);
-    }
-    else {
-        path.lineTo(rightCorner);
-        path.lineTo(sceneRectangle.width(), sceneRectangle.y());
-    }
+    path.moveTo(sceneRectangle.x(), sceneRectangle.height());
+    path.lineTo(leftCorner);
+    path.lineTo(rightCorner);
+    path.lineTo(sceneRectangle.width(), sceneRectangle.y());
+    //END
+
+    pen.setWidth(penWidth);
     ui.histogramGraphicsView->scene()->addPath(path, pen);
 
     //-- fit all in viewer
@@ -357,25 +377,23 @@ void ImageLutWidget::draw () {
 //---------------------- fillHistogramTable ------------------------
 template<class DATATYPE>
 void ImageLutWidget::fillHistogramTable(DATATYPE * data, unsigned int dataDim, DATATYPE minVal, DATATYPE maxVal) {
-    DATATYPE dataValue;
-
-    unsigned int i;
-    unsigned int pointIndex;
-
-    int intervalLength = (int) ((maxVal - minVal) / (nbHistoBins - 1.0));
-    highestGreyLevel = 0;
-
-    for ( i = 0; i < dataDim; i++ ) {
-        dataValue = data[i];
+    // scale factor from [min,max] to [0..nbHistoBins]
+    DATATYPE intervalLength = (DATATYPE) ((maxVal - minVal) / nbHistoBins);
 
+    //-- build histogram
+    for (unsigned int i = 0; i < dataDim; i++ ) {
         // Find the corresponding interval index
-        pointIndex = (unsigned int) ((dataValue - minVal) / intervalLength);
+        unsigned int pointIndex = (unsigned int) ((data[i] - minVal) / intervalLength);
+        // build the histogram (increment the corresponding value)
         greyLevels[pointIndex] += 1;
-
-        if (greyLevels[pointIndex] > highestGreyLevel)
-            highestGreyLevel = greyLevels[pointIndex];
     }
 
+    //-- compute max value
+    highestGreyLevel = 0;
+    for (unsigned int i = 0; i<nbHistoBins; i++) {
+        if (greyLevels[i] > highestGreyLevel)
+            highestGreyLevel = greyLevels[i];
+    }
 }
 
 //---------------------- resizeEvent  ----------------------------
@@ -473,11 +491,11 @@ void ImageLutWidget::lineEditLUTWindowChanged (  ) {
 void ImageLutWidget::invertButtonClicked() {
     invert = !invert;
     applyLUT();
-/*    QColor maxColor = ui.maxColor->palette().button().color();
-    QColor minColor = ui.minColor->palette().button().color();
-    ui.maxColor->setPalette(QPalette(minColor));
-    ui.minColor->setPalette(QPalette(maxColor));
-    */
+    /*    QColor maxColor = ui.maxColor->palette().button().color();
+        QColor minColor = ui.minColor->palette().button().color();
+        ui.maxColor->setPalette(QPalette(minColor));
+        ui.minColor->setPalette(QPalette(maxColor));
+        */
     updateGradient();
 }
 
