@@ -53,7 +53,7 @@ using namespace camitk;
 
 // ---------------------- constructor ----------------------------
 ActionStateMachine::ActionStateMachine(int &argc, char ** argv, QString inputFileName, QString outputDirectory) throw(AbortException) :
-    Application("Action State Machine", argc, argv) {
+    Application("camitk-actionstatemachine", argc, argv) {
     statesMap = new QMap<QString, ActionState *>();
 
     // Atributes initialization
@@ -97,7 +97,7 @@ ActionStateMachine::ActionStateMachine(int &argc, char ** argv, QString inputFil
     mainWindow->setWindowSubtitle(name);
 
     // Prepare the output directory
-    QFile::copy(":/resources/log2html.xsl", saveDirectory.absolutePath() + "/log2html.xsl");
+    QFile::copy(":/logXSL", saveDirectory.absolutePath() + "/log2html.xsl");
 
     // Starting the Machine !!
 
@@ -143,6 +143,9 @@ void ActionStateMachine::initMainWindow() {
 
     // force no redirection to console (to see error message if they occur)
     mainWindow->redirectToConsole(false);
+
+    // set the specific actions state machine icon
+    mainWindow->setWindowIcon(QPixmap(":/applicationIcon"));
 }
 
 // ---------------------- checkSCXMLFile ----------------------------
