@@ -55,7 +55,10 @@ using namespace camitk;
 #include <QDockWidget>
 
 // ------------- constructor -----------------
-ImpMainWindow::ImpMainWindow() : MainWindow( "imp ") {
+ImpMainWindow::ImpMainWindow() : MainWindow( "imp" ) {
+    // set the specific actions state machine icon
+    setWindowIcon(QPixmap(":/applicationIcon"));
+
     // init all other GUI
     initActions();
     initMenuBar();
@@ -75,7 +78,7 @@ ImpMainWindow::ImpMainWindow() : MainWindow( "imp ") {
     showStatusBar(true);
 }
 
- // ------------- destructor -----------------
+// ------------- destructor -----------------
 ImpMainWindow::~ImpMainWindow() {
 }
 
@@ -87,7 +90,7 @@ void ImpMainWindow::aboutToShow() {
     updateRecentDocumentsMenu();
 
     // check autoload for files and load if needed
-    if ( autoloadLastOpened && Application::getRecentDocuments().size() > 0 ) {
+    if ( autoLoadLastOpened && Application::getRecentDocuments().size() > 0 ) {
         Application::open ( Application::getRecentDocuments().last().absoluteFilePath() );
     }
 }
@@ -132,7 +135,7 @@ void ImpMainWindow::initActions() {
         QMessageBox::critical(this,"Application Error", "This application <b>needs</b> the Application Action Extension and could not find it in any of the action extension directories (<tt>" + Core::getActionDirectories().join(", ") + "</tt>).<br/><br/>Please check your CamiTK configuration and/or installation<br/><br/>E.g., run <tt>camitk-config --config</tt> to check the action extension directories and your installation.");
         exit(EXIT_FAILURE);
     }
-    
+
     //--- actions of the File menu
     // get the CamiTK actions
     fileOpen = Application::getAction ("Open")->getQAction();
@@ -283,7 +286,7 @@ void ImpMainWindow::updateActionStates() {
     fileSave->setEnabled ( selectedIsTopLevel && Application::getSelectedComponents().first()->getTopLevelComponent()->getModified() ); // save available only if needed
     fileSaveAs->setEnabled ( nrOfSelectedItems > 0  ); // no need to be top level to be saved as in a compatible format
     fileClose->setEnabled ( selectedIsTopLevel );
- 
+
     //-- update edit menu
     editClearSelection->setEnabled ( nrOfSelectedItems > 0 );
 
@@ -357,18 +360,16 @@ void ImpMainWindow::resetWindows() {
             addDockWidget ( Qt::LeftDockWidgetArea, it.value() );
             it.value()->show();
         }
-        else
-            if (it.value()->widget() == PropertyExplorer::getInstance()->getWidget()) {
-                removeDockWidget(it.value());
-                addDockWidget(Qt::LeftDockWidgetArea, it.value() );
-                it.value()->show();
-            }
-            else
-                if (it.value()->widget() == ActionViewer::getActionViewer()->getWidget()) {
-                    removeDockWidget(it.value());
-                    addDockWidget(Qt::RightDockWidgetArea, it.value());
-                    it.value()->show();
-                }
+        else if (it.value()->widget() == PropertyExplorer::getInstance()->getWidget()) {
+            removeDockWidget(it.value());
+            addDockWidget(Qt::LeftDockWidgetArea, it.value() );
+            it.value()->show();
+        }
+        else if (it.value()->widget() == ActionViewer::getActionViewer()->getWidget()) {
+            removeDockWidget(it.value());
+            addDockWidget(Qt::RightDockWidgetArea, it.value());
+            it.value()->show();
+        }
     }
 
     showStatusBar(true);
@@ -472,8 +473,8 @@ void ImpMainWindow::editSettings() {
 
     // construct a dynamic property object
     QObject *myProperties = new QObject;
-    myProperties->setObjectName ( "imp" );
-    myProperties->setProperty ( "autoLoadLastOpened", autoloadLastOpened );
+    myProperties->setObjectName(Application::getName());
+    myProperties->setProperty ( "autoLoadLastOpened", autoLoadLastOpened );
     settingsDialog.editSettings ( myProperties );
 
     // edit all viewers that have properties
@@ -491,11 +492,11 @@ void ImpMainWindow::editSettings() {
     }
 
     // update the property
-    autoloadLastOpened = myProperties->property ( "autoLoadLastOpened" ).toBool();
+    autoLoadLastOpened = myProperties->property ( "autoLoadLastOpened" ).toBool();
     // save it in the settings
     QSettings & settings = Application::getSettings();
-    settings.beginGroup ( "imp" );
-    settings.setValue ( "autoLoadLastOpened", autoloadLastOpened );
+    settings.beginGroup ( Application::getName() + ".Application" );
+    settings.setValue ( "autoLoadLastOpened", autoLoadLastOpened );
     settings.endGroup();
 
     // check if there are anything to change in the data directory menu (for data directory manager)
@@ -511,9 +512,9 @@ void ImpMainWindow::initSettings() {
 
     QSettings & settings = Application::getSettings();
 
-    settings.beginGroup ( "ImpMainWindow" );
+    settings.beginGroup (Application::getName() + ".Application");
     // the autoload option
-    autoloadLastOpened = settings.value ( "autoloadLastOpened", false ).toBool(); // default false
+    autoLoadLastOpened = settings.value ( "autoLoadLastOpened", false ).toBool(); // default false
     settings.endGroup();
 }
 
@@ -536,7 +537,7 @@ void ImpMainWindow::openRecentDocuments() {
         else
             QMessageBox::warning(this, "Open Recent", "Recent document:<br/>" + action->data().toString() + "<br/>Does not exist anymore, sorry...");
     }
-            
+
 }
 
 // ------------------------------ updateRecentDocumentsMenu -------------------------------
