@@ -142,9 +142,10 @@ void ExtensionGenerator::setXmlFileName(QString xmlFileName) throw (QString) {
 void ExtensionGenerator::generateCMakeLists() throw (QString) {
     // Copying FindCamiTK.cmake
     std::cout << "Copying FindCamiTK.cmake..." << std::endl;
-    QDir cMakeModuleDir = camitk::Core::getTestDataDir();
-    cMakeModuleDir.cdUp();
-    cMakeModuleDir.cd("cmake");
+    QDir cMakeModuleDir(camitk::Core::getGlobalInstallDir());
+    if (!cMakeModuleDir.cd("share/"+QString(camitk::Core::shortVersion)+"/cmake")) {
+        std::cerr << "Error: directory \"" << QString(QString(camitk::Core::getGlobalInstallDir())+"share/"+QString(camitk::Core::shortVersion)+"/cmake").toStdString() << "\" not found" << std::endl;
+   }
     QFile findCamiTK(cMakeModuleDir.canonicalPath()+"/"+"FindCamiTK.cmake");
     std::cout << "Copying " << findCamiTK.fileName().toStdString() << std::endl;
     findCamiTK.copy(this->srcDir.canonicalPath() + "/" + "FindCamiTK.cmake");
