@@ -46,10 +46,15 @@ void ExtensionManager::autoload() {
     QDir privateLibDir(Core::getGlobalInstallDir());
     if (privateLibDir.cd("lib/"+QString(Core::shortVersion))) {
         QByteArray privateLibDirPath = privateLibDir.canonicalPath().toUtf8();
+#ifdef WIN32
+        // update path for windows
         QByteArray path = qgetenv("PATH");
         path.append(";");
         path.append(privateLibDirPath);
         qputenv("PATH",path);
+#endif
+        // update the application / qt plugins library path
+        Application::instance()->addLibraryPath(privateLibDirPath);
     }
 
     autoload(COMPONENT);
@@ -129,12 +134,20 @@ void ExtensionManager::autoload(ExtensionManager::ExtensionType type) {
                 errorStrings << QString("Plugin " + fileName + ", no error (you need to decrease your number of dependency level, or contact the CamiTK SDK developer team)");
             }
         }
+
         QMessageBox::warning(NULL, "ExtensionManager Opening Error...",
                              "AutoLoad plugin failed after " + QString::number(tryNr) + " tries for the following extension(s):<ul><li>"
                              + errorStrings.join("</li><li>")
                              + "</li></ul>"
                              + "List of library paths:<ul><li>"
                              + Application::instance()->libraryPaths().join("</li><li>")
+                             + "</li></ul>"
+                             + "List of path:<ul><li>"
+#ifdef WIN32
+                             + QString(qgetenv("PATH")).split(":").join("</li><li>")
+#else
+                             + QString(qgetenv("LD_LIBRARY_PATH")).split(":").join("</li><li>")
+#endif
                              + "</li></ul>");
 
     }
@@ -157,7 +170,7 @@ void ExtensionManager::autoload(ExtensionManager::ExtensionType type) {
     settings.endGroup();
 
     foreach(QString userRegisteredExtensionFile, userRegisteredExtensions) {
-        loadExtension(COMPONENT, userRegisteredExtensionFile);
+        loadExtension(type, userRegisteredExtensionFile);
     }
 
 }
@@ -214,6 +227,14 @@ bool ExtensionManager::loadExtension(ExtensionManager::ExtensionType type, QStri
     }
     else {
         pluginLoader.unload();  // to make sure we could try again later
+
+        // try to load the missing shared object directly from private dir (give absolute path)
+        QRegExp libname("\\((lib.*): cannot open shared object file");
+        if (libname.indexIn(pluginLoader.errorString(), 0)!= -1) {
+            QString privateLibToLoad=Core::getGlobalInstallDir() + "/lib/" + QString(Core::shortVersion) + "/" + libname.cap(1);
+            QLibrary privateLib(privateLibToLoad);
+            privateLib.load();
+        }
     }
 
     return returnValue;
@@ -221,14 +242,14 @@ bool ExtensionManager::loadExtension(ExtensionManager::ExtensionType type, QStri
 }
 
 // -------------------- getInstallationString --------------------
-QString ExtensionManager::getInstallationString(QString file) {    
+QString ExtensionManager::getInstallationString(QString file) {
     QString whichInstallDir;
     QDir dir(QFileInfo(file).absolutePath());
     // go up three levels (one for the extension name, one for the camitk short version name, one for the lib name)
     dir.cdUp();
     dir.cdUp();
     dir.cdUp();
-    
+
     QString absolutePath = dir.absolutePath();
     if (absolutePath == Core::getGlobalInstallDir()) {
         whichInstallDir = "[G]";
