@@ -146,9 +146,23 @@ bool Component::event(QEvent * e) {
 
 // ---------------------- updateProperty ----------------------------
 void Component::updateProperty(QString name, QVariant value) {
-    CAMITK_INFO("Component", "updateProperty", "The value of property \"" << name.toStdString() << "\" has changed to: " << value.toString().toStdString() << " (" << metaObject()->className() << "::updateProperty(..) not implemented properly)");
+    CAMITK_INFO("Component", "updateProperty", "The value of property \"" << name.toStdString() << "\" has changed to: \"" << value.toString().toStdString() << "\"" << endl << "If you want to take this change/property into account, please redefine method \"updateProperty(QString name, QVariant value)\" in class " << metaObject()->className());
+    
 }
 
+// ---------------------- setDynamicProperty ----------------------------
+bool Component::setDynamicProperty(const char* name, const QVariant& value, const char* description, bool isReadOnly) {
+    // to check if static property exists: getPropertyObject()->metaObject()->indexOfProperty(name)>=0
+    // to check if dynamic property exists getPropertyObject()->dynamicPropertyNames().contains(name)
+    // TODO
+    //   - call QObject setProperty
+    //   - if description is not empty: modify description
+    //   - modify readOnly property
+
+    // it is essential to give everything to the property object (by default it is this instance, but it can be otherwise
+    // if the Component subclass has a specific property class)
+    return getPropertyObject()->setProperty(name,value);
+}
 
 // -------------------- isTopLevel --------------------
 bool Component::isTopLevel() const {
