@@ -425,6 +425,14 @@ public:
      */
     void updateProperty(QString name, QVariant value);
 
+    /** specific setProperty method that can pass the description and the readOnly property.
+     *  If the property already exists, it will just change its value (and descripion or readOnly property).
+     *  @param name the name of the property
+     *  @param value the new value for the given property
+     *  @param description the description associated with this property
+     *  @param isReadOnly if true, then the property cannot be modified in the GUI
+     */
+    virtual bool setDynamicProperty(const char *name, const QVariant &value, const char *description = "", bool isReadOnly=false);
     ///@}
 
     /**
