@@ -535,7 +535,7 @@ void Slice::setSlice(int s) {
         }
 
         /* 2D Actors                                    */
-        // Passing from index coordinates to real coordinates without spacing.
+        // Tranform index coordinates to real coordinates without spacing.
         reslicedToVolumeCoords(orgInAxial, orgInReal);
 
         // Real coordinates are rounded and spacing is taken into account.
@@ -558,17 +558,15 @@ void Slice::setSlice(double x, double y, double z) {
     double ijk[3] = {0.0, 0.0, 0.0};
     double xyz[3] = {x, y, z};
 
-    // Passing from real coordinates to index coordinates
+    // Tranform real coordinates to index coordinates
     volumeToReslicedCoords(xyz, ijk);
 
     // Set pixel position in current slice.
     setPixelRealPosition( ijk[0], ijk[1], 0.0 );
 
-    // Round the slice number due to matrix inverse. It will be troncated in setSlice( int) procedure.
-    ijk[2] += 0.5;
-
-    // Set the slice number.
-    setSlice(ijk[2]);
+    // Set the slice number
+    // Round the slice number due to matrix inverse before sending it to setSlice(int)
+    setSlice(rint(ijk[2]));
 }
 
 
