@@ -555,11 +555,10 @@ void RendererWidget::pick() {
     // Screen coordinates
     QPoint mousePointerPos = QCursor::pos();
 
-	// Widget coordinates
+    // Widget coordinates
     QPoint inWidgetCoord = mapFromGlobal(mousePointerPos);
 
     pickActor(inWidgetCoord.x(), inWidgetCoord.y());
-//	pickActor(mousePointerPos.x(), mousePointerPos.y());
 }
 
 // --------------------- pickActor -----------------------------------
@@ -574,10 +573,10 @@ void RendererWidget::pickActor(int x, int y) {
 
     // perform picking operation
     int picked = picker->Pick(GetInteractor()->GetEventPosition()[0],
-                 GetInteractor()->GetEventPosition()[1],
-                 0,  // always zero.
-                 GetInteractor()->GetRenderWindow()->GetRenderers()->GetFirstRenderer()); //x, height() - y - 1, 0.0, renderer);
-    
+                              GetInteractor()->GetEventPosition()[1],
+                              0,  // always zero.
+                              GetInteractor()->GetRenderWindow()->GetRenderers()->GetFirstRenderer());
+
     if (picked) {
         // if something was picked, cry it out loud!
         if (picker->GetProp3Ds()->GetLastProp() != NULL)
@@ -671,7 +670,7 @@ void RendererWidget::updateAxes() {
     zLength = fabs(bounds[5] - bounds[4]);
     double maxLength = (xLength > yLength) ?
                        ((xLength > zLength) ? xLength : zLength) :
-                               ((yLength > zLength) ? yLength : zLength);
+                           ((yLength > zLength) ? yLength : zLength);
 
     // the size of the axe is about 10% the size of the bound
     maxLength /= 10.0;
